/* ARCADEmini simulator (unix, console)
 * version 0.5 date 2003-09-03
 * part of the ARCADEmini project - http[s]://arcademini.schuermans.info/
 * Copyright (C) 2003 sphaera <sphaera@geekness.de>
 *                and 1stein <1stein@schuermans.info>
 * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
 */

#include <stdio.h>
#include <signal.h>
#include <unistd.h>

#include "am_dev.h"
#include "display.h"

int end = 0;

//signal handler to end the program
void end_signal( int sig_no )
{
  sig_no += 0; //keep compiler-happy
  end = 1;
}

//main program
int main( int arg_c, char * * arg_v )
{
  FILE * p_file;
  st_am_state am_state;
  unsigned short msec;

  //issue short info
  puts( "ARCADEmini simulator (unix, console)\n"
        "version 0.5 date 2003-09-03\n"
        "part of the ARCADEmini project - http[s]://arcademini.schuermans.info/\n"
        "Copyright (C) 2003 sphaera <sphaera@geekness.de>\n"
        "                and 1stein <1stein@schuermans.info>\n"
        "Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html\n"
      );

  //wrong parameters
  if( arg_c != 2 )
  {
    printf( "syntax: %s <input-file>\n", arg_v[0] );
    return 1;
  }

  //open input-file
  p_file = fopen( arg_v[1], "rb" );
  if( p_file == NULL )
  {
    printf( "could not open \"%s\" for reading\n", arg_v[1] );
    return -1;
  }

  //initialize state
  if( am_dev_init_state( &am_state, p_file ) != 0 )
  {
    printf( "error in ambin-file \"%s\"\n", arg_v[1] );
    return -1;
  }

  //install signal handler to end program
  signal( SIGHUP, end_signal );
  signal( SIGINT, end_signal );
  signal( SIGTERM, end_signal );

  //main loop
  printf( "\x01B""c" );
  while( !end )
  {
    //execute a command
    msec = am_dev_exec( &am_state );
    //diplay new picture
    display_picture( am_state.picture );
    //wait for delay
    usleep( (unsigned long)msec * 1000 );
  }

  //close input-file
  fclose( p_file );

  //end
  return 0;
}
